# OpenAQ Python API Wrapper

!!! warning

    The OpenAQ python client is still under active development and may be unstable until
    a v1.0.0 release. 


The OpenAQ Python API wrapper provides a low-level python interface for interacting the with OpenAQ API. The library is compatible with Python versions 3.8, 3.9, 3.10, 3.11 and 3.12

Features:

* Synchronous and Asynchronous client options.
* Deserialized response classes.
* Fully type annotated.

